<?php
/*
Plugin Name: Fedya's WP SMTP
Description: A simple plugin to configure custom SMTP settings. Лесен плъгин за конфигуриране на персонализирани SMTP настройки.
Version: 1.0
Author: fedya Serafiev
website: https://urocibg.eu/
License: GPLv2 or later
License URI: https://www.gnu.org/licenses/gpl-2.0.html
*/

// Prevent direct access
if (!defined('ABSPATH')) {
    exit;
}

// Add the admin menu
function fedya_smtp_menu() {
    add_menu_page(
        'Fedya SMTP Settings',
        'Fedya SMTP',
        'manage_options',
        'fedya-smtp',
        'fedya_smtp_page',
        'dashicons-email'
    );
}
add_action('admin_menu', 'fedya_smtp_menu');

// Enqueue admin styles
function fedya_smtp_enqueue_styles($hook_suffix) {
    // Check if we are on the plugin's settings page
    if ($hook_suffix === 'toplevel_page_fedya-smtp') {
        wp_enqueue_style(
            'fedya-smtp-admin-style', // Unique identifier
            plugin_dir_url(__FILE__) . 'css/admin-style.css', // Path to the CSS file
            array(), // Dependencies (if any)
            '1.0', // Version
            'all' // Media type
        );
    }
}
add_action('admin_enqueue_scripts', 'fedya_smtp_enqueue_styles');

// Display the settings page
function fedya_smtp_page() {
    ?>
    <div class="wrap">
        <h1>Fedya SMTP Settings</h1>
        <form method="post" action="options.php">
            <?php
            settings_fields('fedya_smtp_options');
            do_settings_sections('fedya-smtp');
            submit_button();
            ?>
        </form>
        
        <!-- Test Email Section -->
        <hr>
        <h2>Send Test Email</h2>
        <form method="post" action="">
            <table class="form-table">
                <tr>
                    <th scope="row">Test Email To:</th>
                    <td>
                        <input type="email" name="test_email" required>
                        <?php submit_button('Send Test Email', 'secondary', 'send_test_email', false); ?>
                    </td>
                </tr>
            </table>
        </form>
    </div>
    <?php
}

// Register settings
function fedya_smtp_settings() {
    register_setting('fedya_smtp_options', 'fedya_smtp_options');

    add_settings_section(
        'fedya_smtp_section',
        'SMTP Configuration',
        'fedya_smtp_section_callback',
        'fedya-smtp'
    );

    // Add all settings fields
    $fields = array(
        'smtp_host' => array(
            'title' => 'SMTP Host',
            'type' => 'text'
        ),
        'smtp_port' => array(
            'title' => 'SMTP Port',
            'type' => 'port'
        ),
        'smtp_username' => array(
            'title' => 'SMTP Username',
            'type' => 'text'
        ),
        'smtp_password' => array(
            'title' => 'SMTP Password',
            'type' => 'password'
        ),
        'smtp_encryption' => array(
            'title' => 'Encryption',
            'type' => 'encryption'
        ),
        'from_email' => array(
            'title' => 'From Email',
            'type' => 'email'
        ),
        'from_name' => array(
            'title' => 'From Name',
            'type' => 'text'
        )
    );

    foreach ($fields as $field_id => $field) {
        add_settings_field(
            $field_id,
            $field['title'],
            'fedya_smtp_field_callback',
            'fedya-smtp',
            'fedya_smtp_section',
            array(
                'id' => $field_id,
                'type' => $field['type']
            )
        );
    }
}
add_action('admin_init', 'fedya_smtp_settings');

function fedya_smtp_section_callback() {
    echo '<p>Enter your SMTP settings below:</p>';
}

function fedya_smtp_field_callback($args) {
    $options = get_option('fedya_smtp_options');
    $value = isset($options[$args['id']]) ? $options[$args['id']] : '';
    
    switch ($args['type']) {
        case 'port':
            $ports = array('25', '465', '587');
            foreach ($ports as $port) {
                echo "<label><input type='radio' name='fedya_smtp_options[{$args['id']}]' value='$port'" . 
                     checked($value, $port, false) . " /> $port</label> ";
            }
            break;
            
        case 'encryption':
            echo "<select name='fedya_smtp_options[{$args['id']}]'>"
                . "<option value='none'" . selected($value, 'none', false) . ">None</option>"
                . "<option value='ssl'" . selected($value, 'ssl', false) . ">SSL</option>"
                . "<option value='tls'" . selected($value, 'tls', false) . ">TLS</option>"
                . "</select>";
            break;
            
        case 'password':
            echo "<input type='password' name='fedya_smtp_options[{$args['id']}]' value='$value' class='regular-text' />";
            break;
            
        case 'email':
            echo "<input type='email' name='fedya_smtp_options[{$args['id']}]' value='$value' class='regular-text' />";
            break;
            
        default:
            echo "<input type='text' name='fedya_smtp_options[{$args['id']}]' value='$value' class='regular-text' />";
            break;
    }
}

// Handle test email
function fedya_smtp_handle_test_email() {
    if (isset($_POST['send_test_email']) && isset($_POST['test_email'])) {
        $to = sanitize_email($_POST['test_email']);
        $subject = 'SMTP Test Email';
        $message = 'This is a test email from your WordPress site using Fedya SMTP plugin. Това е тестов имейл от вашия WordPress сайт с помощта на Fedya SMTP плъгин.';
        
        $headers = array('Content-Type: text/html; charset=UTF-8');
        
        if (wp_mail($to, $subject, $message, $headers)) {
            add_settings_error(
                'fedya_smtp_messages', 
                'fedya_smtp_message', 
                'Test email sent successfully!', 
                'updated'
            );
        } else {
            add_settings_error(
                'fedya_smtp_messages', 
                'fedya_smtp_message', 
                'Failed to send test email. Please check your SMTP settings.', 
                'error'
            );
        }
    }
}
add_action('admin_init', 'fedya_smtp_handle_test_email');

// Configure PHPMailer
function fedya_smtp_configure_smtp($phpmailer) {
    $options = get_option('fedya_smtp_options');
    
    if (!empty($options['smtp_host'])) {
        $phpmailer->isSMTP();
        $phpmailer->Host = $options['smtp_host'];
        $phpmailer->SMTPAuth = true;
        $phpmailer->Port = $options['smtp_port'];
        $phpmailer->Username = $options['smtp_username'];
        $phpmailer->Password = $options['smtp_password'];
        
        if (!empty($options['smtp_encryption']) && $options['smtp_encryption'] != 'none') {
            $phpmailer->SMTPSecure = $options['smtp_encryption'];
        }
        
        if (!empty($options['from_email'])) {
            $phpmailer->From = $options['from_email'];
        }
        if (!empty($options['from_name'])) {
            $phpmailer->FromName = $options['from_name'];
        }
    }
}
add_action('phpmailer_init', 'fedya_smtp_configure_smtp');

// Activation hook
function fedya_smtp_activate() {
    if (!get_option('fedya_smtp_options')) {
        add_option('fedya_smtp_options', array(
            'smtp_host' => '',
            'smtp_port' => '587',
            'smtp_username' => '',
            'smtp_password' => '',
            'smtp_encryption' => 'tls',
            'from_email' => '',
            'from_name' => ''
        ));
    }
}
register_activation_hook(__FILE__, 'fedya_smtp_activate');
