<?php
// security.php
if (!defined('ABSPATH')) {
    exit;
}

// Enhanced encryption key management
function get_encryption_key() {
    $key = get_option('fedya_smtp_encryption_key');
    if (!$key) {
        $key = wp_generate_password(32, true, true);
        update_option('fedya_smtp_encryption_key', $key);
    }
    return $key;
}

// Improved password encryption
function encrypt_password($password) {
    if (empty($password)) return '';
    
    $key = get_encryption_key();
    $method = "aes-256-cbc";
    $iv_length = openssl_cipher_iv_length($method);
    $iv = openssl_random_pseudo_bytes($iv_length);
    
    $encrypted = openssl_encrypt(
        $password,
        $method,
        $key,
        0,
        $iv
    );
    
    return base64_encode($iv . $encrypted);
}

// Improved password decryption
function decrypt_password($encrypted) {
    if (empty($encrypted)) return '';
    
    try {
        $key = get_encryption_key();
        $method = "aes-256-cbc";
        $iv_length = openssl_cipher_iv_length($method);
        
        $decoded = base64_decode($encrypted);
        $iv = substr($decoded, 0, $iv_length);
        $encrypted_password = substr($decoded, $iv_length);
        
        return openssl_decrypt(
            $encrypted_password,
            $method,
            $key,
            0,
            $iv
        );
    } catch (Exception $e) {
        error_log('Fedya SMTP Decryption Error: ' . $e->getMessage());
        return '';
    }
}

// Add security headers
function fedya_smtp_security_headers() {
    header('X-Content-Type-Options: nosniff');
    header('X-Frame-Options: SAMEORIGIN');
    header('X-XSS-Protection: 1; mode=block');
    header('Referrer-Policy: strict-origin-when-cross-origin');
}
add_action('admin_init', 'fedya_smtp_security_headers');